@@ -12,68 +12,68 @@ import pprint
 
 # Environment
 
-from global_chem.environment.emerging_perfluoroalkyls import EmergingPerFluoroAlkyls
+from environment.emerging_perfluoroalkyls import EmergingPerFluoroAlkyls
 
 # Materials
 
-from global_chem.materials.clay.montmorillonite_adsorption import MontmorilloniteAdsorption
-from global_chem.materials.polymers.common_monomer_repeating_units import CommonMonomerRepeatingUnits
+from materials.clay.montmorillonite_adsorption import MontmorilloniteAdsorption
+from materials.polymers.common_monomer_repeating_units import CommonMonomerRepeatingUnits
 
 # Medicinal Chemistry - Cannabinoids
 
-from global_chem.medicinal_chemistry.cannabinoids.cannabinoids import Cannabinoids
+from medicinal_chemistry.cannabinoids.cannabinoids import Cannabinoids
 
 # Medicinal Chemistry - Warheads
 
-from global_chem.medicinal_chemistry.warheads.electrophillic_warheads_for_kinases import ElectrophilicWarheadsForKinases
-from global_chem.medicinal_chemistry.warheads.common_warheads_covalent_inhibitors import CommonWarheadsCovalentInhibitors
+from medicinal_chemistry.warheads.electrophillic_warheads_for_kinases import ElectrophilicWarheadsForKinases
+from medicinal_chemistry.warheads.common_warheads_covalent_inhibitors import CommonWarheadsCovalentInhibitors
 
 # Medicinal Chemistry - Rings
 
-from global_chem.medicinal_chemistry.rings.rings_in_drugs import RingsInDrugs
-from global_chem.medicinal_chemistry.rings.iupac_blue_book_rings import IUPACBlueBookRings
-from global_chem.medicinal_chemistry.rings.phase_2_hetereocyclic_rings import Phase2HetereoCyclicRings
+from medicinal_chemistry.rings.rings_in_drugs import RingsInDrugs
+from medicinal_chemistry.rings.iupac_blue_book_rings import IUPACBlueBookRings
+from medicinal_chemistry.rings.phase_2_hetereocyclic_rings import Phase2HetereoCyclicRings
 
 # Medicinal Chemistry - Scaffolds
 
-from global_chem.medicinal_chemistry.scaffolds.iupac_blue_book import IUPACBlueBook
-from global_chem.medicinal_chemistry.scaffolds.privileged_scaffolds import PrivilegedScaffolds
-from global_chem.medicinal_chemistry.scaffolds.common_r_group_replacements import CommonRGroupReplacements
+from medicinal_chemistry.scaffolds.iupac_blue_book import IUPACBlueBook
+from medicinal_chemistry.scaffolds.privileged_scaffolds import PrivilegedScaffolds
+from medicinal_chemistry.scaffolds.common_r_group_replacements import CommonRGroupReplacements
 
 # Proteins Kinases
 
-from global_chem.proteins.kinases.braf.braf_inhibitors import BRAFInhibitors
-from global_chem.proteins.kinases.scaffolds.privileged_kinase_inhibitors import PrivilegedKinaseInhibitors
+from proteins.kinases.braf.braf_inhibitors import BRAFInhibitors
+from proteins.kinases.scaffolds.privileged_kinase_inhibitors import PrivilegedKinaseInhibitors
 
 # Organic Synthesis
 
-from global_chem.organic_synthesis.solvents.common_organic_solvents import CommonOrganicSolvents
-from global_chem.organic_synthesis.protecting_groups.amino_acid_protecting_groups import AminoAcidProtectingGroups
-from global_chem.organic_synthesis.bidendate_phosphine_ligands.nickel_ligands import NickelBidendatePhosphineLigands
+from organic_synthesis.solvents.common_organic_solvents import CommonOrganicSolvents
+from organic_synthesis.protecting_groups.amino_acid_protecting_groups import AminoAcidProtectingGroups
+from organic_synthesis.bidendate_phosphine_ligands.nickel_ligands import NickelBidendatePhosphineLigands
 
 # Narcotics
 
-from global_chem.narcotics.pihkal import Pihkal
-from global_chem.narcotics.schedule_one import ScheduleOne
-from global_chem.narcotics.schedule_two import ScheduleTwo
-from global_chem.narcotics.schedule_three import ScheduleThree
-from global_chem.narcotics.schedule_four import ScheduleFour
-from global_chem.narcotics.schedule_five import ScheduleFive
+from narcotics.pihkal import Pihkal
+from narcotics.schedule_one import ScheduleOne
+from narcotics.schedule_two import ScheduleTwo
+from narcotics.schedule_three import ScheduleThree
+from narcotics.schedule_four import ScheduleFour
+from narcotics.schedule_five import ScheduleFive
 
 # Interstellar Space
 
-from global_chem.interstellar_space.interstellar_space import InterstellarSpace
+from interstellar_space.interstellar_space import InterstellarSpace
 
 # Biopharmaceutics - Excipients
 
-from global_chem.formulation.excipients.biopharmaceutics_class_three.cimetidine_acyclovir import CimetidineAndAcyclovir
+from formulation.excipients.biopharmaceutics_class_three.cimetidine_acyclovir import CimetidineAndAcyclovir
 
 # Miscellaneous
 
-from global_chem.miscellaneous.vitamins import Vitamins
-from global_chem.miscellaneous.open_smiles import OpenSmiles
-from global_chem.miscellaneous.amino_acids import AminoAcids
-from global_chem.miscellaneous.regex_patterns import CommonRegexPatterns
+from miscellaneous.vitamins import Vitamins
+from miscellaneous.open_smiles import OpenSmiles
+from miscellaneous.amino_acids import AminoAcids
+from miscellaneous.regex_patterns import CommonRegexPatterns
 
 class Node:
 
